"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const semantic_ui_react_1 = require("semantic-ui-react");
const stores_1 = require("../stores");
const renderPlaceholder = (limit) => {
    const output = [];
    for (let i = 0; i < limit; i += 1) {
        const key = `list-placeholder-${i}`;
        output.push(react_1.default.createElement(semantic_ui_react_1.List.Item, { key: key },
            react_1.default.createElement(semantic_ui_react_1.Loader, { active: true, size: "small", inline: "centered" })));
    }
    return output;
};
exports.LazyList = ({ entity, item, limit = 20, children }) => {
    const [offset, setOffset] = react_1.useState(0);
    const [page, setPage] = react_1.useState(1);
    const { send: findCount, response: count } = stores_1.useGraphQuery({
        entity,
        method: "findCount"
    });
    const { send: find, response = [], loading } = stores_1.useGraphQuery({
        entity,
        method: "find",
        args: [
            {},
            {
                limit,
                offset
            }
        ]
    }, [entity, limit, offset]);
    const onPageChange = react_1.useCallback((_, { activePage }) => {
        const p = activePage;
        setPage(p);
        setOffset((p - 1) * limit);
    }, [limit]);
    react_1.useEffect(() => {
        const cancel = findCount();
        return cancel;
    }, [entity]);
    react_1.useEffect(() => {
        const cancel = find();
        return cancel;
    }, [page, entity]);
    const renderItem = react_1.useCallback((r) => react_1.default.createElement(semantic_ui_react_1.List.Item, { as: item, value: r, key: r._id }), [item]);
    const renderChildren = react_1.useCallback((r) => children && children({ "data-value": r, key: r._id }), [item, children]);
    let content = null;
    if (loading && !response.length) {
        content = renderPlaceholder(limit);
    }
    else if (!loading && !response.length) {
        content = react_1.default.createElement(semantic_ui_react_1.Header, { content: "No results", textAlign: "center", block: true });
    }
    else if (children && typeof children === "function") {
        content = response.map(renderChildren);
    }
    else {
        content = response.map(renderItem);
    }
    return (react_1.default.createElement(semantic_ui_react_1.Segment, { padded: true },
        react_1.default.createElement(semantic_ui_react_1.List, { divided: true }, content),
        react_1.default.createElement(semantic_ui_react_1.Grid, { centered: true, padded: true },
            react_1.default.createElement(semantic_ui_react_1.Pagination, { disabled: !count, defaultActivePage: page, totalPages: count ? Math.ceil(count / limit) : 1, onPageChange: onPageChange }))));
};
