"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importDefault(require("react"));
const react_dom_1 = tslib_1.__importDefault(require("react-dom"));
const sdk_1 = require("@hiro-ui/sdk");
const orm_1 = tslib_1.__importDefault(require("@hiro-graph/orm"));
const stores_1 = require("../stores");
const components_1 = require("../components");
const helpers_1 = require("../helpers");
const HiroGraphMappings = helpers_1.getMappings();
const getConfigFromEnv = () => {
    const graphUrl = process.env.REACT_APP_GRAPH_URL;
    const authUrl = process.env.REACT_APP_AUTH_URL || `${graphUrl}/api/6/auth/ui/`;
    const redirectUrl = process.env.REACT_APP_REDIRECT_URL || `${graphUrl}/api/6/auth/ui-redirect`;
    const clientId = process.env.REACT_APP_CLIENT_ID;
    const config = {
        graphUrl,
        authUrl,
        clientId,
        redirectUrl
    };
    if (Object.values(config).every(Boolean)) {
        return config;
    }
    return undefined;
};
class HiroApp {
    constructor({ config, reducers, sagas } = {}) {
        this.setup = () => tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { ready, state, token, graphUrl } = yield sdk_1.initSdk(this.config);
            let orm;
            if (token && graphUrl) {
                orm = new orm_1.default({
                    endpoint: graphUrl,
                    token
                }, HiroGraphMappings);
            }
            const store = stores_1.init({
                state,
                reducers: this.reducers,
                sagas: this.sagas,
                orm
            });
            return { store, orm, ready };
        });
        this.render = (children, target) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { store, orm, ready } = yield this.setup();
            react_dom_1.default.render(react_1.default.createElement(components_1.HiroAppRoot, { store: store, orm: orm }, children), target, ready);
        });
        this.config = config;
        this.reducers = reducers;
        this.sagas = sagas;
        if (!config) {
            this.config = getConfigFromEnv();
        }
    }
}
exports.HiroApp = HiroApp;
