"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const redux_react_hook_1 = require("redux-react-hook");
const lodash_es_1 = require("lodash-es");
const constants_1 = require("../constants");
const constants_2 = require("./constants");
const actions_1 = require("./actions");
exports.useGraphState = () => {
    const mapState = react_1.useCallback(state => lodash_es_1.get(state, [constants_1.HIRO_NAMESPACE, constants_2.GRAPH_NAMESPACE]), []);
    return redux_react_hook_1.useMappedState(mapState);
};
exports.useGraphQuery = (query, deps = []) => {
    const dispatch = redux_react_hook_1.useDispatch();
    let id = `${query.entity}-${query.method}`;
    if (query.args) {
        id = `${id}-${JSON.stringify(query.args)}`;
    }
    const send = react_1.useCallback(() => {
        dispatch(actions_1.graphQuery.request(Object.assign({}, query, { id })));
        return () => void dispatch(actions_1.graphQuery.cancel({ id }));
    }, [deps]);
    const mapState = react_1.useCallback(state => lodash_es_1.get(state, [constants_1.HIRO_NAMESPACE, constants_2.GRAPH_NAMESPACE, id], {
        loading: true
    }), [deps]);
    const state = redux_react_hook_1.useMappedState(mapState);
    return {
        send,
        loading: state.loading,
        response: state.response,
        error: state.error
    };
};
