"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const redux_1 = require("redux");
const redux_saga_1 = tslib_1.__importDefault(require("redux-saga"));
const effects_1 = require("redux-saga/effects");
const errors_1 = require("./errors");
const constants_1 = require("./constants");
const graph_1 = require("./graph");
tslib_1.__exportStar(require("./errors"), exports);
tslib_1.__exportStar(require("./graph"), exports);
// Combine built-in sagas
function* mainSaga(orm) {
    yield effects_1.fork(graph_1.handleGraphRequests, orm);
}
function init({ state, reducers, sagas, orm } = {}) {
    // Combine built-in reducers with exeternal ones
    const rootReducer = redux_1.combineReducers(Object.assign({ [constants_1.HIRO_NAMESPACE]: redux_1.combineReducers({
            [errors_1.ERROR_NAMESPACE]: errors_1.errorReducer,
            [graph_1.GRAPH_NAMESPACE]: graph_1.graphReducer
        }) }, reducers));
    const composeEnhancers = window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__ || redux_1.compose;
    const sagaMiddleware = redux_saga_1.default();
    // Create store
    const store = redux_1.createStore(rootReducer, state, 
    /* preloadedState, */
    composeEnhancers(redux_1.applyMiddleware(sagaMiddleware)));
    // Run built-in saga
    sagaMiddleware.run(mainSaga, orm);
    // Run external sagas
    if (sagas) {
        for (const saga of sagas) {
            sagaMiddleware.run(saga);
        }
    }
    return store;
}
exports.init = init;
